<?php
namespace App\Model;

/*
 * Functions to interface with `books` table
 */
class Book
{
    protected $database;

    function __construct($database)
    {
        $this->database = $database;
    }

    function getAllBooks()
    {
        try {
            $query = "SELECT books.*, COALESCE(COALESCE(votes.value,0),0) as score "
                . " FROM books "
                . " LEFT JOIN votes ON (books.id = votes.book_id) "
                . " GROUP BY books.id "
                . " ORDER BY score DESC";
            $stmt = $this->database->prepare($query);
            $stmt->execute();
            return $stmt->fetchAll();
        } catch (\Exception $e) {
            throw $e;
        }
    }

    function getBook($id)
    {
        try {
            $query = "SELECT * FROM books WHERE id = :bookId";
            $stmt = $this->database->prepare($query);
            $stmt->bindParam(':bookId', $id);
            $stmt->execute();
            return $stmt->fetch();
        } catch (\Exception $e) {
            throw $e;
        }
    }

    function addBook($title, $description, $ownerId = null)
    {
        if (empty($ownerId)) {
            $ownerId = 0;
        }

        try {
            $query = "INSERT INTO books (name, description, owner_id) VALUES (:name, :description, :ownerId)";
            $stmt = $this->database->prepare($query);
            $stmt->bindParam(':name', $title);
            $stmt->bindParam(':description', $description);
            $stmt->bindParam(':ownerId', $ownerId);
            return $stmt->execute();
        } catch (\Exception $e) {
            throw $e;
        }
    }

    function updateBook($bookId, $title, $description)
    {
        try {
            $query = "UPDATE books SET name=:name, description=:description WHERE id=:bookId";
            $stmt = $this->database->prepare($query);
            $stmt->bindParam(':name', $title);
            $stmt->bindParam(':description', $description);
            $stmt->bindParam(':bookId', $bookId);
            return $stmt->execute();
        } catch (\Exception $e) {
            throw $e;
        }
    }

    function deleteBook($bookId)
    {
        try {
            $query = "DELETE FROM books WHERE id=:bookId";
            $stmt = $this->database->prepare($query);
            $stmt->bindParam(':bookId', $bookId);
            return $stmt->execute();
        } catch (\Exception $e) {
            throw $e;
        }
    }
}