<?php

use Slim\Http\Request;
use Slim\Http\Response;

// Open Routes
$app->get('/books', function (Request $request, Response $response, array $args) {
    $args['allBooks'] = $this->book->getAllBooks();
    $args['vote'] = $this->vote;
    return $this->renderer->render($response, 'books.php', $args);
});
$app->get('/', function (Request $request, Response $response, array $args) {
    return $this->renderer->render($response, 'index.php', $args);
});
$app->get('/login', function (Request $request, Response $response, array $args) {
    return $this->renderer->render($response, 'login.php', $args);
});
$app->post('/login', function (Request $request, Response $response, array $args) {
    return $response->withRedirect('/login');
});
$app->get('/logout', function (Request $request, Response $response, array $args) {
    return $response->withRedirect('/login');
});
$app->get('/register', function (Request $request, Response $response, array $args) {
    return $this->renderer->render($response, 'register.php', $args);
});
$app->post('/register', function (Request $request, Response $response, array $args) {
    return $response->withRedirect('/register');
});

// Authenticated User
$app->group('', function(Slim\App $app) {
    $app->get('/add', function (Request $request, Response $response, array $args) {
        return $this->renderer->render($response, 'add.php', $args);
    });
    $app->post('/add', function (Request $request, Response $response, array $args) {
        $book = $request->getParsedBody();

        if ($this->book->addBook($book['title'], $book['description'])) {
            $this->session->getFlashBag()->add('success', 'Book Added');
            return $response->withRedirect('/books');
        }
        $this->session->getFlashBag()->add('error', 'Unable to Add Book');
        return $response->withRedirect('/add');
    });
    $app->get('/vote', function (Request $request, Response $response, array $args) {
        $this->vote->vote(
            $request->getQueryParam('bookId'), 
            $request->getQueryParam('vote')
        );
        
        return $response->withRedirect('/books');
    });
});

// Authorized Owners
$app->group('', function(Slim\App $app) {
    $app->get('/delete/{bookId}', function (Request $request, Response $response, array $args) {
        $book = $this->book->getBook($args['bookId']);
        if ($this->book->deleteBook($book['id'])) {
            $this->session->getFlashBag()->add('success', 'Book Deleted');
        } else {
            $this->session->getFlashBag()->add('error', 'Unable to Delete Book');
        }
        return $response->withRedirect('/books');
    });
    $app->get('/edit/{bookId}', function (Request $request, Response $response, array $args) {
        $args['book'] = $this->book->getBook($args['bookId']);
        return $this->renderer->render($response, 'edit.php', $args);
    });
    $app->post('/edit/{bookId}', function (Request $request, Response $response, array $args) {
        $book = $this->book->getBook($args['bookId']);
        $form = $request->getParsedBody();

        if ($this->book->updateBook($book['id'], $form['title'], $form['description'])) {
            $this->session->getFlashBag()->add('success', 'Book Updated');
            return $response->withRedirect('/books');
        }

        $this->session->getFlashBag()->add('error', 'Unable to Update Book');
        return $response->withRedirect('/edit/'.$book['id']);
    });
});